tiled.adapters.mapping.MapAdapter
=================================

.. currentmodule:: tiled.adapters.mapping

.. autoclass:: MapAdapter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MapAdapter.__init__
      ~MapAdapter.authenticated_as
      ~MapAdapter.get
      ~MapAdapter.items
      ~MapAdapter.keys
      ~MapAdapter.new_variation
      ~MapAdapter.read
      ~MapAdapter.register_query
      ~MapAdapter.register_query_lazy
      ~MapAdapter.search
      ~MapAdapter.sort
      ~MapAdapter.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MapAdapter.access_policy
      ~MapAdapter.background_tasks
      ~MapAdapter.entries_stale_after
      ~MapAdapter.entries_stale_at
      ~MapAdapter.include_routers
      ~MapAdapter.items_indexer
      ~MapAdapter.keys_indexer
      ~MapAdapter.metadata
      ~MapAdapter.metadata_stale_after
      ~MapAdapter.metadata_stale_at
      ~MapAdapter.must_revalidate
      ~MapAdapter.principal
      ~MapAdapter.query_registry
      ~MapAdapter.structure_family
      ~MapAdapter.values_indexer
   
   